@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-02-06'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -290,7 +290,7 @@ sub gen_perinci_cmdline_completer_script {
             "# get words\n",
             'my $shell;', "\n",
             'my ($words, $cword);', "\n",
-            'if ($ENV{COMP_LINE}) { $shell = "bash"; require Complete::Bash; ($words,$cword) = @{ Complete::Bash::parse_cmdline() }; }', "\n",
+            'if ($ENV{COMP_LINE}) { $shell = "bash"; require Complete::Bash; ($words,$cword) = @{ Complete::Bash::parse_cmdline() }; ($words,$cword) = @{ Complete::Bash::join_wordbreak_words($words,$cword) }; }', "\n",
             'elsif ($ENV{COMMAND_LINE}) { $shell = "tcsh"; require Complete::Tcsh; ($words,$cword) = @{ Complete::Tcsh::parse_cmdline() }; }', "\n",
             '@ARGV = @$words;', "\n",
             "\n",
@@ -450,7 +450,7 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.07 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2016-01-18.
+This document describes version 0.08 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2016-02-06.
 
 =head1 FUNCTIONS
 
